@@ -1274,6 +1274,9 @@ ResultsStream *FlatpakBackend::search(const AbstractResourcesBackend::Filters &f
                 for (uint i = 0; i < refs->len; i++) {
                     FlatpakInstalledRef *ref = FLATPAK_INSTALLED_REF(g_ptr_array_index(refs, i));
                     auto resource = getAppForInstalledRef(installation, ref);
+#if FLATPAK_CHECK_VERSION(1, 1, 2)
+                    resource->setAvailableVersion(QString::fromUtf8(flatpak_installed_ref_get_appdata_version(ref)));
+#endif
                     resource->setState(AbstractResource::Upgradeable);
                     updateAppSize(resource);
                     if (resource->resourceType() == FlatpakResource::Runtime) {
@@ -1296,7 +1299,7 @@ ResultsStream *FlatpakBackend::search(const AbstractResourcesBackend::Filters &f
         return stream;
     } else if (filter.state == AbstractResource::Installed) {
         auto stream = new ResultsStream(QStringLiteral("FlatpakStream-installed"));
-        auto f = [this, stream] {
+        auto f = [this, stream, filter] {
             QVector<AbstractResource *> resources;
             for (auto installation : m_installations) {
                 g_autoptr(GError) localError = nullptr;
@@ -1315,6 +1318,9 @@ ResultsStream *FlatpakBackend::search(const AbstractResourcesBackend::Filters &f
                         continue;
 
                     auto resource = getAppForInstalledRef(installation, ref);
+                    if (!filter.search.isEmpty() && !resource->name().contains(filter.search, Qt::CaseInsensitive))
+                        continue;
+
                     if (resource->resourceType() == FlatpakResource::Runtime) {
                         resources.prepend(resource);
                     } else {
